$VAR1 = {
         'en' => {
                  'firstname'           => 'Firstname',
                  'street'              => 'Street',
                  'email'               => 'Email Adress',
                  'save'                => 'Save',
                  'password'            => 'Password',
                  'wrongusername'       => 'Wrong Username',
                  'editmessage'         => 'Edit',
                  'caption'             => 'Caption',
                  'regmessage'          => 'You receive this email from Lindnerei.de ',
                  'category'            => 'Category',
                  'haveacount'          => 'You already have an Acount',
                  'sites'               => 'Sites',
                  'nomail'              => 'No Email Adress given.',
                  'name'                => 'Name',
                  'newmenu'             => 'Create new Menu',
                  'username'            => 'User',
                  'trash'               => 'Trash',
                  'preview'             => 'Preview',
                  'chars'               => 'Chars left:',
                  'newmessage'          => 'New Topic',
                  'userexits'           => 'This name is olready in use.<br/>',
                  'wrongpass'           => 'Wrong Password',
                  'mailsendet'          => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'edit'                => 'Bearbeiten',
                  'city'                => 'City',
                  'summary'             => 'Summary',
                  'inserttext'          => 'Insert Text',
                  'postcode'            => 'Postcode',
                  'pass'                => 'Password',
                  'showwindow'          => 'Show Windows',
                  'familyname'          => 'Family Name',
                  'choosefile'          => 'Choose Attachment',
                  'databases'           => 'Databases',
                  'database'            => 'Database',
                  'phone'               => 'Phone Number',
                  'reply'               => 'Antworten',
                  'register'            => 'Register',
                  'mailsubject'         => 'Register',
                  'headline'            => 'Headline',
                  'realy'               => 'Realy',
                  'body'                => 'Body',
                  'newpass'             => 'New Password',
                  'retry'               => 'retry',
                  'upentry'             => 'Sort',
                  'downentry'           => 'Sort',
                  'edittreeviewentry'   => 'Edit',
                  'deletetreeviewentry' => 'Delete',
                  'addtreeviewentry'    => 'Add new entry',
                  'edittreeview'        => 'Edit',
                  'savetreeviewentry'   => 'Save',
                  'newtreeviewentry'    => 'New Entry',
                  'search'              => 'Search',
                  'edittree'            => 'Edit',
                  'links'               => 'Bookmarks',
                  'bookmarks'           => 'Bookmarks',
                  'answers'             => 'Answers',
                  'getpass'             => 'Lost Password',
                  'lostpass'            => 'Lost passwort',
                  'execsql'             => 'Exec Sql',
                  'newentry'            => 'New Entry',
                  'showtabledetails'    => 'show Table Details',
                  'mysqldump'           => 'Mysql dump',
                  'deleteentry'         => 'Delete Entry',
                  'editentry'           => 'Edit Entry',
                  'openfile'            => 'Files',
                  'deletefile'          => 'Files',
                  'fileexists'          => 'File already Exists',
                  'newfileadded'        => 'New File created',
                  'chmodfile'           => 'Files',
                  'newfile'             => 'Files',
                  'makedir'             => 'Files',
                  'newdir'              => 'Files',
                  'files'               => 'Files',
                  'readmore'            => 'Read More',
                  'reg'                 => 'Register ',
                  'welcome'             => 'Welcome',
                  'logout'              => 'Logout',
                  'insertpass'          => 'Insert Password',
                  'insertname'          => 'Insert Your Name',
                  'admincenter'         => 'Admin Center',
                  'env'                 => 'Envoirement Variables',
                  'properties'          => 'Properties',
                  'impressum'           => 'Impressum',
                  'gbook'               => 'Gbook',
                  'settings'            => 'Settings',
                  'translate'           => 'Translate',
                  't_regtext'           => 'Register',
                  'gbook_body'          => 'Write your entry',
                  'news'                => 'News',
                  'navigation'          => 'Navigation',
                  'savefile'            => 'Save',
                  'floodtext'           => 'To many Posts',
                  'help'                => 'Hilfe',
         },
         'de' => {
                  'firstname'           => 'Vorname',
                  'street'              => 'Strasse',
                  'email'               => 'Emailadresse',
                  'save'                => 'Speichern',
                  'password'            => 'Passwort',
                  'wrongusername'       => 'Sie haben keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
                  'editmessage'         => 'Bearbeiten',
                  'caption'             => '&#220;berschrift',
                  'regmessage'          => 'Sie ehalten diese Email weil versucht wurde sich auf damit bei uns zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
                  'category'            => 'Kategorie',
                  'haveacount'          => 'Sie haben bereits einen Acount',
                  'sites'               => 'Seiten',
                  'nomail'              => 'Sie haben keine email adresse angegeben.',
                  'name'                => 'Name',
                  'newmenu'             => 'Neues Menu erstellen',
                  'username'            => 'Benutzer',
                  'trash'               => 'M&#252;lleimer',
                  'preview'             => 'Vorschau',
                  'delete'              => 'L&#246;schen',
                  'chars'               => 'Zeichen &#252;brig:',
                  'newmessage'          => 'Neue Nachricht',
                  'sitemap'             => '&#252;bersicht',
                  'userexits'           => 'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
                  'wrongpass'           => 'Falsches Passwort',
                  'mailsendet'          => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'edit'                => 'Bearbeiten',
                  'city'                => 'Stadt',
                  'summary'             => 'Zusammenfassung',
                  'inserttext'          => 'Text einf&#252;gen',
                  'postcode'            => 'Postleitzahl',
                  'pass'                => 'Passwort',
                  'showwindow'          => 'Fenster anzeigen',
                  'familyname'          => 'Nachname',
                  'choosefile'          => 'File ausw&#228;hlen',
                  'databases'           => 'Datenbanken',
                  'database'            => 'Datenbank',
                  'phone'               => 'Telefonnummer',
                  'reply'               => 'Antworten',
                  'answers'             => 'Antworten',
                  'register'            => 'Registrieren',
                  'mailsubject'         => 'Registrieren',
                  'headline'            => '&#220;berschrift',
                  'realy'               => 'Wirklich',
                  'body'                => 'Text',
                  'newpass'             => 'Neues Passwort',
                  'retry'               => 'Wiederholen',
                  'upentry'             => 'Sotieren',
                  'downentry'           => 'Sotieren',
                  'edittreeviewentry'   => 'Bearbeiten',
                  'deletetreeviewentry' => 'L&#246;sche',
                  'addtreeviewentry'    => 'Hinzuf&#252;gen',
                  'edittreeview'        => 'Bearbeiten',
                  'savetreeviewentry'   => 'Speichern',
                  'newtreeviewentry'    => 'Neuer Eintrag',
                  'search'              => 'Suchen',
                  'links'               => 'Links',
                  'edittree'            => 'Bearbeiten',
                  'bookmarks'           => 'Lesezeichen',
                  'links'               => 'Lesezeichen',
                  'getpass'             => 'Passwort vergessen',
                  'lostpass'            => 'Passwort vergessen',
                  'execsql'             => 'Exec Sql',
                  'newentry'            => 'Neuer Eintrag',
                  'showtabledetails'    => 'Tabellen Details',
                  'mysqldump'           => 'Mysql dump',
                  'deleteentry'         => 'Eintrag l&#246;schen',
                  'editentry'           => 'Eintrag bearbeiten',
                  'openfile'            => 'Files',
                  'deletefile'          => 'Files',
                  'fileexists'          => 'File already Exists',
                  'newfileadded'        => 'New File created',
                  'chmodfile'           => 'Files',
                  'newfile'             => 'Files',
                  'makedir'             => 'Files',
                  'newdir'              => 'Files',
                  'readmore'            => 'ganzen Atikel lesen',
                  'reg'                 => 'Registrieren',
                  'welcome'             => 'Willkommen',
                  'logout'              => 'Abmelden',
                  'insertpass'          => 'Insert Password',
                  'insertname'          => 'Insert Your Name',
                  'admincenter'         => 'Admin Center',
                  'env'                 => 'Envoirement Variablen',
                  'properties'          => 'Einstellungen',
                  'impressum'           => 'Impressum',
                  'gbook'               => 'G&#228;stebuch',
                  'settings'            => 'Einstellungen',
                  'translate'           => '&#220;bersetzen',
                  't_regtext'           => 'Registrieren',
                  'gbook_body'          => 'Text einf&#252;gen',
                  'news'                => 'Blog',
                  'navigation'          => 'Navigation',
                  'savefile'            => 'Speichern',
                  'floodtext'           => 'Nicht so oft posten',
                  'help'                => 'Hilfe',
         },
};
$lang = $VAR1;

